@@ -3,7 +3,7 @@ Colour extraction routines
 """
 
 try:
-    from colourdistance import closest_by_palette, colour_distance
+    from _speedups import closest_by_palette, colour_distance
 except ImportError:
     from math import sqrt
 
